@@ -21,16 +21,20 @@
 #include <KActionCollection>
 #include <KNotification>
 #include <KLocalizedString>
-#include <KPluginLoader>
 #include <KPluginFactory>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkConfigurationManager>
+#else
+#include <QNetworkInformation>
+#endif
 #include <QDomElement>
 
 #include "kuiserverjobs.h"
 #include "scheduler.h"
 #include "kget_export.h"
 #include "transfer.h"
+#include "transferhandler.h"
 #include "transfergrouphandler.h"
 
 class QDomElement;
@@ -38,7 +42,6 @@ class QDomElement;
 
 class TransferDataSource;
 class TransferGroup;
-class TransferHandler;
 class TransferFactory;
 class TransferTreeModel;
 class TransferTreeSelectionModel;
@@ -467,7 +470,7 @@ class GenericObserver : public QObject
 {
     Q_OBJECT
     public:
-        GenericObserver(QObject *parent = nullptr);
+        explicit GenericObserver(QObject *parent = nullptr);
         ~GenericObserver () override;
 
     public Q_SLOTS:
@@ -485,7 +488,11 @@ class GenericObserver : public QObject
         void slotAbortAfterFinishAction();
         void slotResolveTransferError();
         void slotNotificationClosed();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         void slotNetworkStatusChanged(bool online);
+#else
+        void slotNetworkStatusChanged(QNetworkInformation::Reachability reachability);
+#endif
 
     private:
         bool allTransfersFinished();
@@ -496,6 +503,8 @@ class GenericObserver : public QObject
         QTimer *m_save;
         QTimer *m_finishAction;
         QHash<KNotification*, TransferHandler*> m_notifications;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QNetworkConfigurationManager m_networkConfig;
+#endif
 };
 #endif
