@@ -84,19 +84,19 @@ void mirror::slotResult( KJob *job )
     }
 
     if (m_Urls.size() > minUrlsNeeded)
-        emit urls(m_Urls);
+        Q_EMIT urls(m_Urls);
     deleteLater();
 }
 
 void MirrorSearch ( const QUrl &url, QObject *receiver, const char *member )
 {
-    mirror *searcher = new mirror();
+    auto *searcher = new mirror();
     searcher->search(url, receiver, member);
 }
 
 void MirrorSearch ( const QString &fileName, QObject *receiver, const char *member )
 {
-    mirror *searcher = new mirror();
+    auto *searcher = new mirror();
     searcher->search(fileName, receiver, member);
 }
 
